@@ -18,6 +18,7 @@ from .params import (
     Request,
     Response,
     ResponseBox,
+    TCollectionResponse,
     TResponse,
 )
 
@@ -33,6 +34,7 @@ __all__ = [
     "Response",
     "ResponseBox",
     "TResponse",
+    "TCollectionResponse",
     "AbstractCollectionParser",
     "CollectionParser",
     "CollectionIterator",
